# Router Test Kit

The motivation for this project is to provide a simple and out-of-the-box, easy-to-use framework for testing (virtual) routers. Initially, the framework was designed to work with OneOS6 routers from OneAccess Networks. It is based on a telnet connection, therefore it is compatible with CISCO routers, Ubuntu Server images etc.

For a thorough documentation (incomplete), see here: [alex-anast.github.io/router-test-kit](https://alex-anast.github.io/router-test-kit/)

## Badges

TODO
![Build Status](https://img.shields.io/github/actions/workflow/status/username/repo/main.yml?branch=main)
![License](https://img.shields.io/github/license/username/repo)

## Table of Contents

- [Router Test Kit](#router-test-kit)
  - [Badges](#badges)
  - [Table of Contents](#table-of-contents)
  - [Demo](#demo)
  - [Description](#description)
  - [Installation](#installation)
  - [Usage](#usage)
  - [Features](#features)
  - [Examples](#examples)
  - [License](#license)

## Demo

## Description

Virtual Router Test Kit is a Python framework for testing routers. It is based on a telnet connection (py-package: `telnetlib`). The framework is designed to be simple and easy to use, with a focus on the most common operations that are performed on a router.

The project is inspired based on the OneOS6 devices of OneAccess Networks (very similar to CISCO), but it is not limited by them. It has been extended to support Ubuntu Server images, and it can be easily extended to support other devices as well, as long as they support a telnet connection.

The easiest way to try it out is to set up two (or more) Virtual Machines and interact with them with the help of this framework. Examples of that, basic and complex, are shown in the [Examples](#examples) section.

## Installation

TODO: setup.py. Try and use pip install

## Usage

TODO: how to use the framework

## Features

TODO: list of features and what they do, per device

## Examples

TODO: A very simple example, a slightly more complex example and finally, the one that already exists

## License

This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details.
